@@ -43,7 +43,8 @@ typedef enum
   PANEL_DEBUG_SYSTRAY          = 1 << 13,
   PANEL_DEBUG_TASKLIST         = 1 << 14,
   PANEL_DEBUG_PAGER            = 1 << 15,
-  PANEL_DEBUG_ITEMBAR          = 1 << 16
+  PANEL_DEBUG_ITEMBAR          = 1 << 16,
+  PANEL_DEBUG_CLOCK            = 1 << 17,
 }
 PanelDebugFlag;
 
