@@ -1374,6 +1374,8 @@ static void
 xfce_panel_plugin_unregister_menu (GtkMenu         *menu,
                                    XfcePanelPlugin *plugin)
 {
+  guint id;
+
   panel_return_if_fail (XFCE_IS_PANEL_PLUGIN (plugin));
   panel_return_if_fail (GTK_IS_MENU (menu));
 
@@ -1381,6 +1383,14 @@ xfce_panel_plugin_unregister_menu (GtkMenu         *menu,
   g_signal_handlers_disconnect_by_func (G_OBJECT (menu),
       G_CALLBACK (xfce_panel_plugin_unregister_menu), plugin);
 
+  /* remove pending source */
+  id = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (menu), "menu-reposition-id"));
+  if (id != 0)
+    {
+      g_source_remove (id);
+      g_object_set_data (G_OBJECT (menu), "menu-reposition-id", GUINT_TO_POINTER (0));
+    }
+
   /* tell panel it needs to unlock */
   xfce_panel_plugin_block_autohide (plugin, FALSE);
 }
@@ -2424,6 +2434,8 @@ xfce_panel_plugin_register_menu (XfcePanelPlugin *plugin,
       G_CALLBACK (xfce_panel_plugin_unregister_menu), plugin);
   g_signal_connect (G_OBJECT (menu), "destroy",
       G_CALLBACK (xfce_panel_plugin_unregister_menu), plugin);
+  g_signal_connect (G_OBJECT (menu), "hide",
+      G_CALLBACK (xfce_panel_plugin_unregister_menu), plugin);
 
   /* tell panel it needs to lock */
   xfce_panel_plugin_block_autohide (plugin, TRUE);
@@ -2679,6 +2691,8 @@ static gboolean
 xfce_panel_plugin_popup_menu_reposition (gpointer data)
 {
   gtk_menu_reposition (data);
+  g_object_set_data (data, "menu-reposition-id", GUINT_TO_POINTER (0));
+
   return FALSE;
 }
 
@@ -2714,6 +2728,7 @@ xfce_panel_plugin_popup_menu (XfcePanelPlugin *plugin,
 {
   GdkGravity widget_anchor, menu_anchor;
   gboolean   popup_at_widget = TRUE;
+  guint      id;
 
   g_return_if_fail (XFCE_IS_PANEL_PLUGIN (plugin));
   g_return_if_fail (GTK_IS_MENU (menu));
@@ -2755,7 +2770,12 @@ xfce_panel_plugin_popup_menu (XfcePanelPlugin *plugin,
   xfce_panel_plugin_register_menu (plugin, menu);
 
   /* since we requested a panel lock, queue a menu repositioning in case the panel is hidden */
-  g_idle_add (xfce_panel_plugin_popup_menu_reposition, menu);
+  id = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (menu), "menu-reposition-id"));
+  if (id != 0)
+    g_source_remove (id);
+
+  id = g_idle_add (xfce_panel_plugin_popup_menu_reposition, menu);
+  g_object_set_data (G_OBJECT (menu), "menu-reposition-id", GUINT_TO_POINTER (id));
 
   /* pop up the menu */
   if (popup_at_widget)
