@@ -146,9 +146,8 @@ migrate_default_start_element_handler (GMarkupParseContext  *context,
             {
               if (strcmp (attribute_names[i], "name") == 0)
                 {
-                  channel_name = attribute_values[i];
-
-                  /* this is an xfce4-panel workaround to make it work
+                  /* instead of `channel_name = attribute_values[i];`,
+                   * this is an xfce4-panel workaround to make it work
                    * with the custom channel names */
                   channel_name = XFCE_PANEL_CHANNEL_NAME;
                 }
@@ -158,7 +157,7 @@ migrate_default_start_element_handler (GMarkupParseContext  *context,
       if (channel_name != NULL)
         {
           /* open the xfconf channel */
-          parser->channel = xfconf_channel_new (channel_name);
+          parser->channel = xfconf_channel_get (channel_name);
         }
       else
         {
@@ -172,6 +171,17 @@ migrate_default_start_element_handler (GMarkupParseContext  *context,
       prop_value = NULL;
       prop_type = NULL;
 
+      /* check if we need to flush an array */
+      if (parser->array != NULL)
+        {
+          prop_path = migrate_default_property_path (parser);
+          xfconf_channel_set_arrayv (parser->channel, prop_path, parser->array);
+          g_free (prop_path);
+
+          xfconf_array_free (parser->array);
+          parser->array = NULL;
+        }
+
       if (G_LIKELY (attribute_names != NULL))
         {
           for (i = 0; attribute_names[i] != NULL; i++)
@@ -292,10 +302,7 @@ migrate_default_end_element_handler (GMarkupParseContext  *context,
   if (strcmp (element_name, "channel") == 0)
     {
       if (G_LIKELY (parser->channel != NULL))
-        {
-          g_object_unref (G_OBJECT (parser->channel));
-          parser->channel = NULL;
-        }
+        parser->channel = NULL;
 
      if (parser->path != NULL)
        {
